@@ -19,6 +19,8 @@ from aws_encryption_sdk.key_providers.kms import StrictAwsKmsMasterKeyProvider
 
 AWS_KMS_KEY_ID = "AWS_ENCRYPTION_SDK_PYTHON_INTEGRATION_TEST_AWS_KMS_KEY_ID"
 AWS_KMS_KEY_ID_2 = "AWS_ENCRYPTION_SDK_PYTHON_INTEGRATION_TEST_AWS_KMS_KEY_ID_2"
+AWS_KMS_MRK_KEY_ID_1 = "AWS_ENCRYPTION_SDK_PYTHON_INTEGRATION_TEST_AWS_KMS_MRK_KEY_ID_1"
+AWS_KMS_MRK_KEY_ID_2 = "AWS_ENCRYPTION_SDK_PYTHON_INTEGRATION_TEST_AWS_KMS_MRK_KEY_ID_2"
 _KMS_MKP = None
 _KMS_MKP_BOTO = None
 
@@ -46,6 +48,16 @@ def get_second_cmk_arn():
     return _get_single_cmk_arn(AWS_KMS_KEY_ID_2)
 
 
+def get_mrk_arn():
+    """Retrieves the target AWS KMS CMK ARN from environment variable."""
+    return _get_single_cmk_arn(AWS_KMS_MRK_KEY_ID_1)
+
+
+def get_second_mrk_arn():
+    """Retrieves the target AWS KMS CMK ARN from environment variable."""
+    return _get_single_cmk_arn(AWS_KMS_MRK_KEY_ID_2)
+
+
 def setup_kms_master_key_provider(cache=True):
     """Reads the test_values config file and builds the requested KMS Master Key Provider."""
     global _KMS_MKP  # pylint: disable=global-statement
@@ -76,3 +88,14 @@ def setup_kms_master_key_provider_with_botocore_session(cache=True):
         _KMS_MKP_BOTO = kms_master_key_provider
 
     return kms_master_key_provider
+
+
+def setup_kms_master_key_provider_with_duplicate_keys(num_keys):
+    """Reads the test_values config file and builds the requested KMS Master Key Provider with multiple copies of
+    the requested key."""
+    assert num_keys > 1
+    cmk_arn = get_cmk_arn()
+    provider = StrictAwsKmsMasterKeyProvider(key_ids=[cmk_arn])
+    for _ in range(num_keys - 1):
+        provider.add_master_key_provider(StrictAwsKmsMasterKeyProvider(key_ids=[cmk_arn]))
+    return provider
