@@ -24,49 +24,49 @@ from .test_crypto import VALUES
 pytestmark = [pytest.mark.unit, pytest.mark.local]
 
 
-@pytest.yield_fixture
+@pytest.fixture
 def patch_default_backend(mocker):
     mocker.patch.object(aws_encryption_sdk.internal.crypto.authentication, "default_backend")
     yield aws_encryption_sdk.internal.crypto.authentication.default_backend
 
 
-@pytest.yield_fixture
+@pytest.fixture
 def patch_serialization(mocker):
     mocker.patch.object(aws_encryption_sdk.internal.crypto.authentication, "serialization")
     yield aws_encryption_sdk.internal.crypto.authentication.serialization
 
 
-@pytest.yield_fixture
+@pytest.fixture
 def patch_ecc_public_numbers_from_compressed_point(mocker):
     mocker.patch.object(aws_encryption_sdk.internal.crypto.authentication, "_ecc_public_numbers_from_compressed_point")
     yield aws_encryption_sdk.internal.crypto.authentication._ecc_public_numbers_from_compressed_point
 
 
-@pytest.yield_fixture
+@pytest.fixture
 def patch_ec(mocker):
     mocker.patch.object(aws_encryption_sdk.internal.crypto.authentication, "ec")
     yield aws_encryption_sdk.internal.crypto.authentication.ec
 
 
-@pytest.yield_fixture
+@pytest.fixture
 def patch_prehashed(mocker):
     mocker.patch.object(aws_encryption_sdk.internal.crypto.authentication, "Prehashed")
     yield aws_encryption_sdk.internal.crypto.authentication.Prehashed
 
 
-@pytest.yield_fixture
+@pytest.fixture
 def patch_base64(mocker):
     mocker.patch.object(aws_encryption_sdk.internal.crypto.authentication, "base64")
     yield aws_encryption_sdk.internal.crypto.authentication.base64
 
 
-@pytest.yield_fixture
+@pytest.fixture
 def patch_build_hasher(mocker):
     mocker.patch.object(Verifier, "_build_hasher")
     yield Verifier._build_hasher
 
 
-@pytest.yield_fixture
+@pytest.fixture
 def patch_set_signature_type(mocker):
     mocker.patch.object(Verifier, "_set_signature_type")
     yield Verifier._set_signature_type
@@ -89,17 +89,22 @@ def test_verifier_from_encoded_point(
     patch_ecc_public_numbers_from_compressed_point,
     patch_base64,
     patch_build_hasher,
+    patch_ec
 ):
     mock_point_instance = MagicMock()
     mock_point_instance.public_key.return_value = sentinel.public_key
     patch_ecc_public_numbers_from_compressed_point.return_value = mock_point_instance
     patch_base64.b64decode.return_value = sentinel.compressed_point
-    algorithm = MagicMock()
+
+    patch_ec.EllipticCurve.__abstractmethods__ = set()
+    mock_algorithm_info = MagicMock(return_value=sentinel.algorithm_info, spec=patch_ec.EllipticCurve)
+    mock_algorithm_info.return_value.name = True
+    mock_algorithm_info.return_value.key_size = True
+    algorithm = MagicMock(signing_algorithm_info=mock_algorithm_info)
 
     verifier = Verifier.from_encoded_point(algorithm=algorithm, encoded_point=sentinel.encoded_point)
 
     patch_base64.b64decode.assert_called_once_with(sentinel.encoded_point)
-    algorithm.signing_algorithm_info.assert_called_once_with()
     patch_ecc_public_numbers_from_compressed_point.assert_called_once_with(
         curve=algorithm.signing_algorithm_info.return_value, compressed_point=sentinel.compressed_point
     )
